@@ -234,7 +234,7 @@ using namespace Rcpp;
             const double s_pred_j = s_pred(j);
 
          // Check if signal is NA or not
-            if(arma::is_finite(s_t_j)) {
+            if(std::isfinite(s_t_j)) {
 
             // Apply TVC-Function
                const arma::field<double> tvc_results = tvc_model_par_(y_t,
@@ -387,7 +387,7 @@ using namespace Rcpp;
      for (int i=0; i<n_cands; i++) {
 
      // Check for NA value
-        if (arma::is_finite(forecast_tvc_t(i))) {  
+        if (std::isfinite(forecast_tvc_t(i))) {  
 
             // Optimization-metric
                switch (metric) {
@@ -933,7 +933,7 @@ using namespace Rcpp;
              for (unsigned int j = 0; j < S.n_cols; j++) {
                
              // Check and Count for NA-Values
-                if (!arma::is_finite(s_t(j))) {
+                if (!std::isfinite(s_t(j))) {
                   new_na_cm.insert_rows(new_na_cm.n_rows, 1);
                   new_na_cm(new_na_cm.n_rows-1) = ctr;                        
                 }
